# parrot 🦜

**parrot** stands for **P**rocessing **A**ll **R**apidly & **R**eliably **O**btained **T**Hz-traces.

parrot is a Python package to load, process, and plot continuously recorded THz data (along with delay line position
data), obtained with electro-optic sampling (EOS), photoconductive antenna (PCA) receivers or similar
techniques.

The documentation of parrot can be found [here](https://puls-lab.github.io/parrot/).

***

## How to install

If you have Python/pip installed, just enter:

```python
pip install parrot
```

and it should install correctly. Otherwise, just download the repository on [GitHub](https://github.com/puls-lab/parrot/).

***

## How to use

Go to [GitHub](https://github.com/puls-lab/parrot/) and look at the files placed in the root directory. If you have
Anaconda (or Python + Jupyter notebook) installed, try the `Example.ipynb` notebook in the root directory.
If you prefer classic Python, check out `Example_compact.py` in the root directory. The distribution comes with some
example data that allows you to see the capabilities of parrot.

***

## Further information

Check out the documentation [here](https://puls-lab.github.io/parrot/).

***

## I have a problem / I have an idea / I found a bug

Please open an issue on [GitHub](https://github.com/puls-lab/parrot/issues).
